from typing import Union, Required, TypedDict, Literal


class CheckResult(TypedDict, total=False):
    """
    check_result.

    A message containing the result of the uptime check.
    """

    guid: Required[str]
    """
    Unique identifier of the uptime check

    Required property
    """

    subscription_id: Required[str]
    """
    Identifier of the subscription that this check was run for

    Required property
    """

    status: Required["CheckStatus"]
    """
    check_status.

    The status of the check

    Required property
    """

    status_reason: Required[Union["CheckStatusReason", None]]
    """
    Aggregation type: oneOf

    Required property
    """

    trace_id: Required[str]
    """
    Trace ID associated with the check-in made

    Required property
    """

    span_id: str
    """ Span ID associated with the check-in made. This is a phantom span generated by the uptime-checker, no real span is ingested. """

    scheduled_check_time_ms: Required[Union[int, float]]
    """
    Timestamp in milliseconds of when the check was schedule to run

    Required property
    """

    actual_check_time_ms: Required[Union[int, float]]
    """
    Timestamp in milliseconds of when the check was actually ran

    Required property
    """

    duration_ms: Required[Union[Union[int, float], None]]
    """
    Duration of the check in ms. Will be null when the status is missed_window

    Required property
    """

    request_info: Required[Union["RequestInfo", None]]
    """
    Aggregation type: oneOf

    Required property
    """



CheckStatus = Union[Literal['success'], Literal['failure'], Literal['missed_window']]
"""
check_status.

The status of the check
"""
CHECKSTATUS_SUCCESS: Literal['success'] = "success"
"""The values for the 'check_status' enum"""
CHECKSTATUS_FAILURE: Literal['failure'] = "failure"
"""The values for the 'check_status' enum"""
CHECKSTATUS_MISSED_WINDOW: Literal['missed_window'] = "missed_window"
"""The values for the 'check_status' enum"""



class CheckStatusReason(TypedDict, total=False):
    """
    check_status_reason.

    Reason for the status, primairly used for failure
    """

    type: Required["CheckStatusReasonType"]
    """
    check_status_reason_type.

    The type of the status reason

    Required property
    """

    description: Required[str]
    """
    A human readable description of the status reason

    Required property
    """



CheckStatusReasonType = Union[Literal['timeout'], Literal['dns_error'], Literal['failure']]
"""
check_status_reason_type.

The type of the status reason
"""
CHECKSTATUSREASONTYPE_TIMEOUT: Literal['timeout'] = "timeout"
"""The values for the 'check_status_reason_type' enum"""
CHECKSTATUSREASONTYPE_DNS_ERROR: Literal['dns_error'] = "dns_error"
"""The values for the 'check_status_reason_type' enum"""
CHECKSTATUSREASONTYPE_FAILURE: Literal['failure'] = "failure"
"""The values for the 'check_status_reason_type' enum"""



class RequestInfo(TypedDict, total=False):
    """
    request_info.

    Additional information about the request made
    """

    request_type: Required["RequestType"]
    """
    request_type.

    The type of HTTP method used for the check

    Required property
    """

    http_status_code: Required[Union[Union[int, float], None]]
    """
    Status code of the successful check-in

    Required property
    """



RequestType = Union[Literal['HEAD'], Literal['GET']]
"""
request_type.

The type of HTTP method used for the check
"""
REQUESTTYPE_HEAD: Literal['HEAD'] = "HEAD"
"""The values for the 'request_type' enum"""
REQUESTTYPE_GET: Literal['GET'] = "GET"
"""The values for the 'request_type' enum"""

